From b02a5be5ad4acae44a17bbfb732ce0b4c4bfe7d9 Mon Sep 17 00:00:00 2001
From: Stefanie Kiemle <stefanie.kiemle@iws.uni-stuttgart.de>
Date: Sun, 2 Apr 2023 17:51:05 +0200
Subject: [PATCH] Remove fv from spatialparams

---
 .../exercise-basic/injection2pspatialparams.hh   | 16 ++++++++--------
 .../exercise-basic/injection2pspatialparams.hh   | 16 ++++++++--------
 2 files changed, 16 insertions(+), 16 deletions(-)

diff --git a/exercises/exercise-basic/injection2pspatialparams.hh b/exercises/exercise-basic/injection2pspatialparams.hh
index 5cc960a3..8ef10ceb 100644
--- a/exercises/exercise-basic/injection2pspatialparams.hh
+++ b/exercises/exercise-basic/injection2pspatialparams.hh
@@ -41,13 +41,13 @@ namespace Dumux {
  *        which uses the isothermal two-phase two-component
  *        fully implicit model.
  */
-template<class FVGridGeometry, class Scalar>
+template<class GridGeometry, class Scalar>
 class InjectionSpatialParams
-: public FVPorousMediumFlowSpatialParamsMP<FVGridGeometry, Scalar, InjectionSpatialParams<FVGridGeometry, Scalar>>
+: public FVPorousMediumFlowSpatialParamsMP<GridGeometry, Scalar, InjectionSpatialParams<GridGeometry, Scalar>>
 {
-    using ThisType = InjectionSpatialParams<FVGridGeometry, Scalar>;
-    using ParentType = FVPorousMediumFlowSpatialParamsMP<FVGridGeometry, Scalar, ThisType>;
-    using GridView = typename FVGridGeometry::GridView;
+    using ThisType = InjectionSpatialParams<GridGeometry, Scalar>;
+    using ParentType = FVPorousMediumFlowSpatialParamsMP<GridGeometry, Scalar, ThisType>;
+    using GridView = typename GridGeometry::GridView;
 
     // get the dimensions of the simulation domain from GridView
     static const int dimWorld = GridView::dimensionworld;
@@ -63,10 +63,10 @@ public:
     /*!
      * \brief The constructor
      *
      * \param fvGridGeometry The finite volume grid geometry
      */
-    InjectionSpatialParams(std::shared_ptr<const FVGridGeometry>& fvGridGeometry)
-    : ParentType(fvGridGeometry)
+    InjectionSpatialParams(std::shared_ptr<const GridGeometry>& gridGeometry)
+    : ParentType(gridGeometry)
     , aquitardPcKrSwCurve_("SpatialParams.Aquitard")
     , aquiferPcKrSwCurve_("SpatialParams.Aquifer")
     {
@@ -63,10 +63,10 @@ public:
      * \brief The constructor
      *
-     * \param fvGridGeometry The finite volume grid geometry
+     * \param gridGeometry The finite volume grid geometry
      */
diff --git a/exercises/solution/exercise-basic/injection2pspatialparams.hh b/exercises/solution/exercise-basic/injection2pspatialparams.hh
index 5cc960a3..8ef10ceb 100644
--- a/exercises/solution/exercise-basic/injection2pspatialparams.hh
+++ b/exercises/solution/exercise-basic/injection2pspatialparams.hh
@@ -41,13 +41,13 @@ namespace Dumux {
  *        which uses the isothermal two-phase two-component
  *        fully implicit model.
  */
-template<class FVGridGeometry, class Scalar>
+template<class GridGeometry, class Scalar>
 class InjectionSpatialParams
-: public FVPorousMediumFlowSpatialParamsMP<FVGridGeometry, Scalar, InjectionSpatialParams<FVGridGeometry, Scalar>>
+: public FVPorousMediumFlowSpatialParamsMP<GridGeometry, Scalar, InjectionSpatialParams<GridGeometry, Scalar>>
 {
-    using ThisType = InjectionSpatialParams<FVGridGeometry, Scalar>;
-    using ParentType = FVPorousMediumFlowSpatialParamsMP<FVGridGeometry, Scalar, ThisType>;
-    using GridView = typename FVGridGeometry::GridView;
+    using ThisType = InjectionSpatialParams<GridGeometry, Scalar>;
+    using ParentType = FVPorousMediumFlowSpatialParamsMP<GridGeometry, Scalar, ThisType>;
+    using GridView = typename GridGeometry::GridView;
 
     // get the dimensions of the simulation domain from GridView
     static const int dimWorld = GridView::dimensionworld;
@@ -63,10 +63,10 @@ public:
     /*!
      * \brief The constructor
      *
      * \param fvGridGeometry The finite volume grid geometry
      */
-    InjectionSpatialParams(std::shared_ptr<const FVGridGeometry>& fvGridGeometry)
-    : ParentType(fvGridGeometry)
+    InjectionSpatialParams(std::shared_ptr<const GridGeometry>& gridGeometry)
+    : ParentType(gridGeometry)
     , aquitardPcKrSwCurve_("SpatialParams.Aquitard")
     , aquiferPcKrSwCurve_("SpatialParams.Aquifer")
     {
@@ -63,10 +63,10 @@ public:
      * \brief The constructor
      *
-     * \param fvGridGeometry The finite volume grid geometry
+     * \param gridGeometry The finite volume grid geometry
      */
-- 
GitLab